@@ -283,7 +283,7 @@ readDatamlx  <- function(project=NULL, datafile=NULL, header=NULL, infoProject=N
   
   iobs1   = findstrcmp(S[[iy]],'.', not=TRUE)
   if (!is.null(imdv))
-    iobs1 <- iobs1[S[iobs1,imdv]==0]
+    iobs1 <- iobs1[S[iobs1,imdv]!=1]
   if (!is.null(ievid))
     iobs1 <- iobs1[S[iobs1,ievid]==0]
   i0 <- c(grep(' .',S[iobs1,iy],fixed=TRUE),grep('. ',S[iobs1,iy],fixed=TRUE))
